@@ -154,5 +154,12 @@ void SQLThread::run(void)
 		commit(sym, buf);
 		Thread::yield();
 	}
+
+	// post actual row count
+	snprintf(nbuf, sizeof(nbuf), "%d", row);
+	lock();
+	interp->setNumber("sql.rows", nbuf);
+	release();
+
 	exit(NULL);
 }
