@@ -303,13 +303,13 @@ Script::Symbol *ScriptInterp::mapDirect(const char *id, unsigned short size)
 
 	if(*id == '.' && frame[stack].script)
 	{
-		cp = strchr(frame[stack].script->filename, '.');
+		cp = (char *)strchr(frame[stack].script->filename, '.');
 		if(cp && !stricmp(cp, ".mod"))
 			setString(partial, sizeof(partial), "mod.");
 		else
 			setString(partial, sizeof(partial), "scr.");
 		addString(partial, sizeof(partial), frame[stack].script->name);
- 		cp = strstr("::", partial);
+ 		cp = (char *)strstr("::", partial);
 		if(cp)
 			*cp = 0;
 		addString(partial, sizeof(partial), id);
@@ -317,7 +317,7 @@ Script::Symbol *ScriptInterp::mapDirect(const char *id, unsigned short size)
 	}
 
 retry:
-	if(!isalpha(*id))
+	if(!isalpha(*id) && *id != '_')
 	{
 		logmissing(id, "invalid");
 		return NULL;
@@ -735,7 +735,8 @@ void ScriptInterp::attach(ScriptCommand *cmdref, ScriptImage *img, Name *scr)
 	session = this;
 	thread = NULL;
 	bool selected = false;
-	
+	Symbol *sym;	
+
 	image = img;
 
 	frame[stack].local = NULL;
@@ -751,6 +752,10 @@ void ScriptInterp::attach(ScriptCommand *cmdref, ScriptImage *img, Name *scr)
 		ilist = ilist->next;
 	}
 
+	sym = mapSymbol("script.authorize", 0);
+	if(sym)
+		sym->type = symTIMER;
+
 	setSymbol("script.home", scrname);
 	mod = ScriptBinder::first;
 	while(mod)
