@@ -1770,7 +1770,7 @@ bool ScriptMethods::scrCall(void)
 	bool trans = false;
 	unsigned idx = 0;
 	Symbol *sym;
-
+	
 	if(!push())
 	{
 		error("stack-overflow");
@@ -2120,7 +2120,7 @@ bool ScriptMethods::scrForeach(void)
 		{
 			snprintf(buffer, sizeof(buffer), "%s", opt);
 			opt = buffer;
-			cp = strchr(opt, pack);
+			cp = (char *)strchr(opt, pack);
 			if(cp)
 				*cp = 0;
 		}		
