@@ -481,7 +481,8 @@ bool Script::commit(Symbol *sym, const char *value)
 	unsigned short pos, npos, len;
 	unsigned offset = 0;
 	int dec = 0;
-	char *dp, *sp;
+	char *dp;
+	const char *sp;
 	long v1, v2;
 	char vbuf[12];
 	ScriptProperty *p;
