@@ -67,6 +67,7 @@
 #define	SCRIPT_RIPPLE_LEVEL 2
 #define	SCRIPT_BINDER_SELECT
 #define	SCRIPT_SERVER_PREFIX
+#define	SCRIPT_DEFINE_TOKENS
 
 #ifndef CCXX_PACKING
 #if defined(__GNUC__)
@@ -275,6 +276,7 @@ public:
 	static unsigned storage(Symbol *sym);
 	static void clear(Symbol *sym);
 	static char decimal;
+	static bool use_definitions;
 	static bool use_macros;
 	static bool use_prefix;
 	static bool use_merge;
@@ -427,6 +429,14 @@ public:
 	 */
 	const char *getTrapName(unsigned id);
 
+	/**
+	 * Alias use modules...
+	 *
+	 * @param id to alias.
+	 * @param id to use.
+	 */
+	void aliasModule(const char *id, const char *use);
+
 protected:
 	/**
 	 * Fetch whether the given keyword is valid for constructor.
@@ -1194,6 +1204,15 @@ public:
 	 */
 	int compile(const char *file, char *name);
 
+	/**
+	 * Compile a defintions library, commonly used for remapping
+	 * tokens to macros.
+	 *
+	 * @return lines of script compiled.
+	 * @param file name of defintions file to compile.
+	 */
+	int compileDefinitions(const char *file);
+
 	/**
 	 * Compile an open stream object into a script.
 	 *
@@ -1451,6 +1470,8 @@ protected:
 	virtual void exitThread(const char *msg);
 	virtual void waitThread(void);
 	virtual void startThread(void);
+
+	bool eventThread(const char *evt, bool flag = true);
 	
 	bool redirect(const char *scr);
 
@@ -1594,6 +1615,8 @@ protected:
 	
 	void exit(const char *errmsg = NULL);
 
+	void exitEvent(const char *evt, bool inherited = true);
+
 	inline bool isExiting(void)
 		{return exiting;};
 
