@@ -67,7 +67,7 @@ void ScriptSymbols::purge(void)
 
 unsigned ScriptSymbols::gather(Symbol **idx, unsigned max, const char *prefix, const char *suffix)
 {
-	char *ext;
+	const char *ext;
 	unsigned key = 0;
 	unsigned count = 0;
 	unsigned pointer, marker;
